Index: /trunk/psLib/src/db/psDB.c
===================================================================
--- /trunk/psLib/src/db/psDB.c	(revision 23914)
+++ /trunk/psLib/src/db/psDB.c	(revision 23915)
@@ -2157,5 +2157,5 @@
 
             // scan through the list and change the logicalOp joining
             // conditionals together to "OR" if a comment of "==" is found
             psListIterator *mCursor = psListIteratorAlloc(item->data.list, 0,
                                       false);
@@ -2163,4 +2163,8 @@
             while ((mItem = psListGetAndIncrement(mCursor))) {
                 if (mItem->comment && psStrcasestr(mItem->comment, "==")) {
+                    logicalOp = "OR";
+                    break;
+                }
+                if (mItem->comment && psStrcasestr(mItem->comment, "LIKE")) {
                     logicalOp = "OR";
                     break;
@@ -2157,5 +2157,5 @@
 
             // scan through the list and change the logicalOp joining
-            // conditionals together to "OR" if a comment of "==" is found
+            // conditionals together to "OR" if a comment of "==" or "LIKE" is found
             psListIterator *mCursor = psListIteratorAlloc(item->data.list, 0,
                                       false);
